@@ -163,7 +163,10 @@ class PyJoke:
             #for k, v in jokes.items():
                 #print "%s: %s" % (k, v)
         except IndexError:
-            return "NO JOKE ERROR"
+            if self.params.lang == "french":
+                return "Pas de blague"
+            else:
+                return "No joke, sorry"
 
 
     ###############################################
